#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const meow_1 = __importDefault(require("meow"));
const chalk_1 = __importDefault(require("chalk"));
const html_1 = require("./html");
const _1 = require(".");
const cli = meow_1.default(`
  Usage
    $ graphql-schema-diff <schema1Location> <schema2Location>

  Options
    --fail-on-dangerous-changes  Exit with error on dangerous changes
    --ignore-breaking-changes  Do not exit with error on breaking changes
    --create-html-output  Creates an HTML file containing the diff
    --html-output-directory  Directory where the HTML file should be stored (Default: './schemaDiff')

  Examples
    $ graphql-schema-diff https://example.com/graphql schema.graphql
`, {
    flags: {
        'fail-on-dangerous-changes': {
            type: 'boolean'
        },
        'ignore-breaking-changes': {
            type: 'boolean'
        },
        'create-html-output': {
            type: 'boolean'
        },
        'html-output-directory': {
            type: 'string',
            default: 'schemaDiff'
        }
    }
});
const [schema1Location, schema2Location] = cli.input;
if (!schema1Location || !schema2Location) {
    throw new Error('Schema locations missing!');
}
_1.getDiff(schema1Location, schema2Location)
    .then(async (result) => {
    if (result === undefined) {
        console.log(chalk_1.default.green('✔ No changes'));
        return;
    }
    const hasBreakingChanges = result.breakingChanges.length !== 0;
    const hasDangerousChanges = result.dangerousChanges.length !== 0;
    console.log(result.diff);
    if (hasDangerousChanges) {
        console.log(chalk_1.default.yellow.bold.underline('Dangerous changes:'));
        for (const change of result.dangerousChanges) {
            console.log(chalk_1.default.yellow('  ⚠ ' + change.description));
        }
    }
    if (hasDangerousChanges && hasBreakingChanges) {
        console.log(); // Add additional line break
    }
    if (hasBreakingChanges) {
        console.log(chalk_1.default.red.bold.underline('BREAKING CHANGES:'));
        for (const change of result.breakingChanges) {
            console.log(chalk_1.default.red('  ✖ ' + change.description));
        }
    }
    if (cli.flags.createHtmlOutput) {
        await html_1.createHtmlOutput(result.diffNoColor, {
            outputDirectory: cli.flags.htmlOutputDirectory
        });
    }
    if ((hasDangerousChanges && cli.flags.failOnDangerousChanges) ||
        (hasBreakingChanges && !cli.flags.ignoreBreakingChanges)) {
        process.exit(1);
        return;
    }
})
    .catch(err => {
    console.error(chalk_1.default.red(`\nERROR: ${err.message}`));
    process.exit(1);
});
